
// Copyright (C) 2008-2009 - INRIA - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

//
// makematrix_magic --
//   Returns the magic matrix of size n.
// Arguments, input
//  n : the size of the matrix to return
// Note : This is a port of Scilab's magic.f
// References
//   "Mathematical recreations and essays", 12th ed.,
//   by w. w. Rouse Ball and h. s. m. Coxeter
//
function a = makematrix_magic ( n )
  a = zeros(n,n)
  if modulo(n,4) == 0 then
    //
    // n is a multiple of 4
    //
    k = 1
    for i = 1:n
    for j = 1:n
      a(i,j) = k
      if int(modulo(i,4)/2) == int(modulo(j,4)/2) then
        a(i,j) = n*n+1 - k
      end
      k = k+1
    end
    end
  else
    //
    // n odd or even
    //
    if modulo(n,2) == 0 then
      m = n/2
    else
      m = n
    end
    i = 1
    j = (m+1)/2
    mm = m*m
    for k = 1: mm
      a(i,j) = k
      i1 = i-1
      j1 = j+1
      if i1 < 1 then
        i1 = m
      end
      if j1 > m then
        j1 = 1
      end
      if int(a(i1,j1))<>0 then
        i1 = i+1
        j1 = j
      end
      i = i1
      j = j1
    end
    if modulo(n,2) <> 0 then
      return
    end
    //
    //     rest of even order
    //
    t = m*m
    for i = 1: m
    for j = 1: m
      im = i+m
      jm = j+m
      a(i,jm) = a(i,j) + 2*t
      a(im,j) = a(i,j) + 3*t
      a(im,jm) = a(i,j) + t
    end
    end
    m1 = (m-1)/2
    if m1==0 then
      return
    end
    for j = 1:m1
      // Swap a(1:m,j) and a(m+1:m+m,j)
      t = a(1:m,j)
      a(1:m,j) = a(m+1:m+m,j)
      a(m+1:m+m,j) = t
    end
    m1 = (m+1)/2
    m2 = m1 + m
    // Swap a(m1,1) and a(m2,1)
    t = a(m1,1)
    a(m1,1) = a(m2,1)
    a(m2,1) = t
    // Swap a(m1,m1) and a(m2,m1)
    t = a(m1,m1)
    a(m1,m1) = a(m2,m1)
    a(m2,m1) = t
    m1 = n+1-(m-3)/2
    if m1 > n then
      return
    end
    for j = m1: n
      t = a(1:m,j)
      a(1:m,j) = a(m+1:m+m,j)
      a(m+1:m+m,j) = t
    end
  end
endfunction

