
// Copyright (C) 2008-2009 - INRIA - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

//
// makematrix_wilkinsonp --
//   Returns the Wilkinson + matrix of size n.
//   "The W+matrix (Wilkinson 1965, p 308) is normally given odd order. 
//   This tridiagonal matrix then has several pairs of close eigenvalues 
//   despite the fact that no superdiagonal element is
//   small. Wilkinson points out that the separation between the two largest eigenvalues
//   is of the order of (n!)-2 so that the power method will be unable to
//   separate them unless n is very small."
// Arguments, input
//  n : the size of the matrix to return
// Reference
//  J.C. Nash, Compact Numerical Methods for Computers: Linear
//  Algebra and Function Minimisation, second edition, Adam Hilger,
//  Bristol, 1990 (Appendix 1).
//  J.H. Wilkinson, The Algebraic Eigenvalue Problem,
//  p. 308, "Close eigenvalues and small beta", W5+
//
function m = makematrix_wilkinsonp ( n )
  m = zeros(n,n);
  for i = 1:n
    m(i,i) = int(n/2)+1-min(i, n- i+1)
  end
  for i = 1:n-1
    m(i,i+1) = 1.0
    m(i+1,i) = 1.0
  end
endfunction

