
// Copyright (C) 2008-2009 - INRIA - Michael Baudin
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt


//
// assert_close --
//   Returns 1 if the two real matrices computed and expected are close,
//   i.e. if the relative distance between computed and expected is lesser than epsilon.
// Arguments
//   computed, expected : the two matrices to compare
//   epsilon : a small number
//
function flag = assert_close ( computed, expected, epsilon )
  if expected==0.0 then
    shift = norm(computed-expected);
  else
    shift = norm(computed-expected)/norm(expected);
  end
  if shift < epsilon then
    flag = 1;
  else
    flag = 0;
  end
  if flag <> 1 then pause,end
endfunction
// Cauchy
computed = gallery("cauchy" , 1:5 );
expected = [
    0.5000    0.3333    0.2500    0.2000    0.1667
    0.3333    0.2500    0.2000    0.1667    0.1429
    0.2500    0.2000    0.1667    0.1429    0.1250
    0.2000    0.1667    0.1429    0.1250    0.1111
    0.1667    0.1429    0.1250    0.1111    0.1000
];
assert_close ( computed, expected, 1.e-3 );
// Cauchy
computed = gallery("cauchy" , 1:5 , 2:6 );
expected = [
    0.3333    0.2500    0.2000    0.1667    0.1429
    0.2500    0.2000    0.1667    0.1429    0.1250
    0.2000    0.1667    0.1429    0.1250    0.1111
    0.1667    0.1429    0.1250    0.1111    0.1000
    0.1429    0.1250    0.1111    0.1000    0.0909
];
assert_close ( computed, expected, 1.e-3 );
// circul
computed = gallery("circul" , 1:5 );
expected = [
     1     2     3     4     5
     5     1     2     3     4
     4     5     1     2     3
     3     4     5     1     2
     2     3     4     5     1
];
assert_close ( computed, expected, %eps );
// circul
x=[
1
2
3
];
computed = gallery("circul" , x );
expected = [
     1     2     3
     3     1     2
     2     3     1
];
assert_close ( computed, expected, %eps );
// gallery(3)
E = [
  -149   -50  -154
   537   180   546
   -27    -9   -25
   ];
A = gallery(3);
assert_close ( A , E , %eps );
// gallery(4)
E = [
        10     7     8     7
         7     5     6     5
         8     6    10     9
         7     5     9    10
   ];
A = gallery(4);
assert_close ( A , E , %eps );
// gallery(5)
E = [
          -9          11         -21          63        -252
          70         -69         141        -421        1684
        -575         575       -1149        3451      -13801
        3891       -3891        7782      -23345       93365
        1024       -1024        2048       -6144       24572
   ]
A = gallery(5);
assert_close ( A , E , %eps );
// gallery(8)
E = [
          611.  196. -192.  407.   -8.  -52.  -49.   29.
          196.  899.  113. -192.  -71.  -43.   -8.  -44.
         -192.  113.  899.  196.   61.   49.    8.   52.
          407. -192.  196.  611.    8.   44.   59.  -23.
           -8.  -71.   61.    8.  411. -599.  208.  208.
          -52.  -43.   49.   44. -599.  411.  208.  208.
          -49.   -8.    8.   59.  208.  208.   99. -911.
           29.  -44.   52.  -23.  208.  208. -911.   99.  
           ];
A = gallery(8);
assert_close ( A , E , %eps );

